#
# spec file for package editorconfig-core-c
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           editorconfig-core-c
Version:        0.12.6
Release:        bp155.1.6
Summary:        EditorConfig core library written in C
License:        BSD-2-Clause AND BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://editorconfig.org/
Source:         https://github.com/editorconfig/editorconfig-core-c/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
Patch0:         editorconfig-core-c-0.12.1-install_paths.patch
Patch1:         editorconfig-core-c-0.12.1-no_timestamp.patch
BuildRequires:  cmake >= 3.5.1
BuildRequires:  doxygen
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libpcre2-8)

%description
EditorConfig makes it easy to maintain the correct coding style when switching
between different text editors and between different projects. The EditorConfig
project maintains a file format and plugins for various text editors which allow
this file format to be read and used by those editors. For information on the
file format and supported text editors, see the EditorConfig website.

%package -n editorconfig
Summary:        Commandline utilities for EditorConfig
Group:          Productivity/Text/Utilities

%description -n editorconfig
EditorConfig makes it easy to maintain the correct coding style when switching
between different text editors and between different projects. The EditorConfig
project maintains a file format and plugins for various text editors which allow
this file format to be read and used by those editors. For information on the
file format and supported text editors, see the EditorConfig website.

This package contains command line utilities.

%package -n libeditorconfig0
Summary:        EditorConfig core library written in C
Group:          System/Libraries

%description -n libeditorconfig0

EditorConfig makes it easy to maintain the correct coding style when switching
between different text editors and between different projects. The EditorConfig
project maintains a file format and plugins for various text editors which allow
this file format to be read and used by those editors. For information on the
file format and supported text editors, see the EditorConfig website.

This package contains shared library.

%package -n libeditorconfig-devel
Summary:        Development files for EditorConfig core library written in C
Group:          Development/Libraries/C and C++
Requires:       libeditorconfig0 = %{version}

%description -n libeditorconfig-devel

EditorConfig makes it easy to maintain the correct coding style when switching
between different text editors and between different projects. The EditorConfig
project maintains a file format and plugins for various text editors which allow
this file format to be read and used by those editors. For information on the
file format and supported text editors, see the EditorConfig website.

This package contains files for developing and building with %{name}

%prep
%autosetup -p1

%build
%cmake \
	-DLIB_SUFFIX=%{_lib} \
	-DINSTALL_HTML_DOC=ON
%make_build

%install
%cmake_install
find %{buildroot}/%{_libdir} -type f -name "*.a" -print -delete

%post -n libeditorconfig0 -p /sbin/ldconfig
%postun -n libeditorconfig0 -p /sbin/ldconfig

%files -n editorconfig
%license LICENSE
%{_bindir}/editorconfig*
%{_mandir}/man1/editorconfig*
%{_mandir}/man5/editorconfig*

%files -n libeditorconfig0
%license LICENSE
%{_libdir}/libeditorconfig.so.0*

%files -n libeditorconfig-devel
%license LICENSE
%doc CONTRIBUTORS README.md
%{_docdir}/libeditorconfig-devel
%{_includedir}/editorconfig
%{_libdir}/libeditorconfig.so
%{_mandir}/man3/editorconfig*
%{_libdir}/pkgconfig/editorconfig.pc
%{_libdir}/cmake/EditorConfig

%changelog
* Tue May  2 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- editorconfig-core-c 0.12.6:
  * CVE-2023-0341: A buffer overflow in ec_blob (boo#1211032)
  * Update property key, value length limits per spec change
* Sun Jun 27 2021 Herbert Graeber <herbert@graeber-clan.de>
- editorconfig-core-c 0.12.5:
  * Fix memory leak which would occur if no .editorconfig files were found
    in the file's ancestry or if an error occurred while ingesting values.
* Sat Nov  7 2020 Andreas Stieger <andreas.stieger@gmx.de>
- editorconfig-core-c 0.12.4:
  * fix various stability issues caused by memory handling
- drop upstream patch now included:
  * 0001-fix-prevent-buffer-overflow-74.patch
* Fri Aug 28 2020 Fabian Vogt <fvogt@suse.com>
- Add patch to fix crash when parsing certain files (boo#1175824):
  * 0001-fix-prevent-buffer-overflow-74.patch
* Tue Dec  4 2018 Herbert Graeber <herbert@graeber-clan.de>
- update to 0.12.3:
  * Bump required minimum cmake version to 2.8.12.
  * Support pcre2 and drop support for pcre.
- use pkconfig to find libpcre2
* Fri May 18 2018 astieger@suse.com
- update to 0.12.2:
  * Add support for pkgconfig
  * Memory leaks and crash fixes
  * Improve error messages
* Mon Aug 14 2017 christophe@krop.fr
- add libeditorconfig0 baselibs, needed for ktexteditor.
* Thu Mar  9 2017 sfalken@opensuse.org
- Edited %%files to clear unpackaged files builderror in
  openSUSE:Factory
* Sat Mar 26 2016 astieger@suse.com
- update to 0.12.1:
  * Fix an issue that libeditorconfig calls exit()
  * Bump required minimum cmake version to 2.8.7
  * Use GNU installation dirs for OS portability
  * Adjust for upstream changes:
    + editorconfig-core-c-0.12.0-install_paths.patch
    to editorconfig-core-c-0.12.1-install_paths.patch
    + editorconfig-core-c-0.12.0-no_timestamp.patch
    to editorconfig-core-c-0.12.1-no_timestamp.patch
* Sat Nov 28 2015 astieger@suse.com
- initial package
- the editorconfig package is not currently linking dynamically
  against the library
